pub struct RenderResults {
pub stats: RendererStats,
pub dirty_rects: Vec<DeviceIntRect>,
pub picture_cache_debug: PictureCacheDebugInfo,
pub did_rasterize_any_tile: bool,
}Expand description
Return type from render(), which contains some repr(C) statistics as well as some non-repr(C) data.
Fields
stats: RendererStatsStatistics about the frame that was rendered.
dirty_rects: Vec<DeviceIntRect>A list of the device dirty rects that were updated this frame. TODO(gw): This is an initial interface, likely to change in future. TODO(gw): The dirty rects here are currently only useful when scrolling is not occurring. They are still correct in the case of scrolling, but will be very large (until we expose proper OS compositor support where the dirty rects apply to a specific picture cache slice / OS compositor surface).
picture_cache_debug: PictureCacheDebugInfoInformation about the state of picture cache tiles. This is only allocated and stored if config.testing is true (such as wrench)
did_rasterize_any_tile: boolWhether any tile was rasterized (had is_valid = false)